@@ -13,8 +13,12 @@
 int random_fn(int small, int big);
 
 // Rolling Functions
-int* perform_roll(unsigned int number_of_dice, unsigned int die_sides,
-                  EXPLOSION_TYPE explode, int start_value);
+int* perform_roll(
+    unsigned int number_of_dice, 
+    unsigned int die_sides,
+    EXPLOSION_TYPE explode, 
+    int start_value
+);
 int* do_roll(roll_params rp);
 
 // #ifdef __cplusplus
